(larch-installation)=
# Installing Larch


## Quick Start

Larch v6 is available via `pip`.  Since it is not yet feature complete, it is not
the default "Larch" for most users, and must be installed as the `larch6` package.

```shell
python -m pip install larch6
```

Once installed, use larch as you normally would, import it in Python as just `larch`:

```python
import larch as lx
```

Version 6 is a work in progress, not a production-ready tool. A lot of things are
working, but not everything. The interface is quite similar to Larch v5 and existing
users will likely find it familiar. If you want to try it out, please do, and feel
free to open issues in the issue tracker. But, please don't expect it to work
perfectly yet, especially for more advanced models.
